==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/RateOfChangeAndMomentumIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { RateOfChangeAndMomentumIndicatorDescription } from "./RateOfChangeAndMomentumIndicatorDescription";
/**
 * @hidden
 */
export let RateOfChangeAndMomentumIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class RateOfChangeAndMomentumIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (RateOfChangeAndMomentumIndicatorDescriptionMetadata.a == null) {
                RateOfChangeAndMomentumIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RateOfChangeAndMomentumIndicatorDescriptionMetadata.c(RateOfChangeAndMomentumIndicatorDescriptionMetadata.a);
            }
            if (a.k(RateOfChangeAndMomentumIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(RateOfChangeAndMomentumIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            RateOfChangeAndMomentumIndicatorDescriptionMetadata.b(a);
            a.ac("RateOfChangeAndMomentumIndicator", () => new RateOfChangeAndMomentumIndicatorDescription());
            a.ab("RateOfChangeAndMomentumIndicator", RateOfChangeAndMomentumIndicatorDescriptionMetadata.a);
        }
    }
    RateOfChangeAndMomentumIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(RateOfChangeAndMomentumIndicatorDescriptionMetadata, 'RateOfChangeAndMomentumIndicatorDescriptionMetadata');
    RateOfChangeAndMomentumIndicatorDescriptionMetadata.a = null;
    return RateOfChangeAndMomentumIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/RateOfChangeAndMomentumIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { RateOfChangeAndMomentumIndicatorDescription } from "./RateOfChangeAndMomentumIndicatorDescription";
/**
 * @hidden
 */
export let RateOfChangeAndMomentumIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class RateOfChangeAndMomentumIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (RateOfChangeAndMomentumIndicatorDescriptionMetadata.a == null) {
                RateOfChangeAndMomentumIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RateOfChangeAndMomentumIndicatorDescriptionMetadata.c(RateOfChangeAndMomentumIndicatorDescriptionMetadata.a);
            }
            if (a.k(RateOfChangeAndMomentumIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(RateOfChangeAndMomentumIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            RateOfChangeAndMomentumIndicatorDescriptionMetadata.b(a);
            a.ae("RateOfChangeAndMomentumIndicator", () => new RateOfChangeAndMomentumIndicatorDescription());
            a.ad("RateOfChangeAndMomentumIndicator", RateOfChangeAndMomentumIndicatorDescriptionMetadata.a);
        }
    }
    RateOfChangeAndMomentumIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(RateOfChangeAndMomentumIndicatorDescriptionMetadata, 'RateOfChangeAndMomentumIndicatorDescriptionMetadata');
    RateOfChangeAndMomentumIndicatorDescriptionMetadata.a = null;
    return RateOfChangeAndMomentumIndicatorDescriptionMetadata;
})();
